.. figure:: https://cloud.githubusercontent.com/assets/109988/9589471/97a005a8-4ffc-11e5-9b8b-3da984d183b3.png
   :alt: 

Getting started
===============

::

    pip install -e git@github.com:newsdev/nyt-pyfec.git
    python -m pyfec.demo
